Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: chrome/browser/chromeos/file_manager/volume_manager.cc

Issue 2945023002: Introduce profile for lock screen apps (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_manager/volume_manager.cc
diff --git a/chrome/browser/chromeos/file_manager/volume_manager.cc b/chrome/browser/chromeos/file_manager/volume_manager.cc
index 191e334797d915265ae1ff14f40d7f71dcfbe8fc..3dbdf66cb08cb60e833255b00b3315c68b18fbe3 100644
--- a/chrome/browser/chromeos/file_manager/volume_manager.cc
+++ b/chrome/browser/chromeos/file_manager/volume_manager.cc
@@ -347,9 +347,12 @@ VolumeManager* VolumeManager::Get(content::BrowserContext* context) {
}
void VolumeManager::Initialize() {
- // If in Sign in profile, then skip mounting and listening for mount events.
- if (chromeos::ProfileHelper::IsSigninProfile(profile_))
+ // If in the Sign in profile pr the lock screen app profile, skip mounting
+ // and listening for mount events.
+ if (chromeos::ProfileHelper::IsSigninProfile(profile_) ||
+ chromeos::ProfileHelper::IsLockScreenAppProfile(profile_)) {
return;
+ }
// Register 'Downloads' folder for the profile to the file system.
const base::FilePath downloads =
« no previous file with comments | « chrome/browser/chromeos/drive/file_system_util.cc ('k') | chrome/browser/chromeos/file_system_provider/mount_path_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698